@@ -30,7 +30,8 @@ _fields = ['description',
            'otp',
            'email',
            'tags',
-           'url']
+           'url',
+           'compromised']
 
 
 class Vault:
@@ -143,10 +144,16 @@ class Vault:
                 return credential
         return None
 
+    def get_decrypted_file_data(self, file):
+        return self._decrypt_field(file['file_data'])
+
+    def get_name(self):
+        return self._name
+
     def _decrypt_entry(self, credential):
         decrypted = {}
         for key, value in credential.items():
-            if key in _fields:
+            if key in _fields and value:
                 decrypted[key] = self._decrypt_field(value)
             else:
                 decrypted[key] = value
@@ -160,7 +167,10 @@ class Vault:
         ciphertext = json.loads(base64.b64decode(field))
         try:
             plaintext = self._cryptor.decrypt(ciphertext, self._get_key())
-            return json.loads(plaintext)
+            try:
+                return json.loads(plaintext)
+            except json.decoder.JSONDecodeError:
+                return plaintext.decode()
         except ValueError:
             raise Error("Decryption failed: wrong passphrase or tampered data")
         except Exception as e:
